==> keep-trinity_3.5.13.2.orig.tar.xz: keep-trinity-3.5.13.2/keep/app/keepmainwindow.h <==
/* This file is part of the Keep project
   Copyright (C) 2005 Jean-Rémy Falleri <jr.falleri@laposte.net>

   Keep is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   Keep is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Keep; if not, write to the
   Free Software Foundation, Inc.,
   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           */

#ifndef _KEEPMAINWINDOW_H_
#define _KEEPMAINWINDOW_H_

#include <kmainwindow.h>
#include <ktabwidget.h>
#include <tqhbox.h>

#include "backup.h"
#include "actionview.h"

class KeepMainWindow: public KMainWindow
{
Q_OBJECT
  TQ_OBJECT
public:
	KeepMainWindow(TQWidget *parent, const char *name);
	~KeepMainWindow();

public slots:
	void slotConfigure();
	void slotConfigureBackup();
	void slotViewLog();

	void slotDaemonAlertState(bool state);

	void slotLoadDaemon();
	void slotUnloadDaemon();
	void slotReloadDaemon();

	void slotAddBackupWizard();
	void slotAddBackup(Backup backup);

	void slotRestoreBackupWizard();

	void slotForceBackup();

	void slotCheckRDB();

	void slotRefreshGUI();
private:
	void initActions();
	void initConnections();
	bool backupSystemRunning();

	ActionView *m_actionView;
};

#endif

==> keep-trinity-14.0.8.tar.xz: keep-trinity-14.0.8/keep/app/keepmainwindow.h <==
/* This file is part of the Keep project
   Copyright (C) 2005 Jean-Rémy Falleri <jr.falleri@laposte.net>

   Keep is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   Keep is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Keep; if not, write to the
   Free Software Foundation, Inc.,
   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           */

#ifndef _KEEPMAINWINDOW_H_
#define _KEEPMAINWINDOW_H_

#include <tdemainwindow.h>
#include <ktabwidget.h>
#include <tqhbox.h>

#include "backup.h"
#include "actionview.h"

class KeepMainWindow: public TDEMainWindow
{
Q_OBJECT
  
public:
	KeepMainWindow(TQWidget *parent, const char *name);
	~KeepMainWindow();

public slots:
	void slotConfigure();
	void slotConfigureBackup();
	void slotViewLog();

	void slotDaemonAlertState(bool state);

	void slotLoadDaemon();
	void slotUnloadDaemon();
	void slotReloadDaemon();

	void slotAddBackupWizard();
	void slotAddBackup(Backup backup);

	void slotRestoreBackupWizard();

	void slotForceBackup();

	void slotCheckRDB();

	void slotRefreshGUI();
private:
	void initActions();
	void initConnections();
	bool backupSystemRunning();

	ActionView *m_actionView;
};

#endif
